@@ -11,6 +11,7 @@
 #  under the License.
 import collections
 
+from oslo_policy import policy
 import pecan
 from webob import exc
 
@@ -101,8 +102,15 @@ def handle_exceptions(operation_name=u._('System')):
             try:
                 return fn(inst, *args, **kwargs)
             except exc.HTTPError:
-                LOG.exception(u._LE('Webob error seen'))
+                LOG.exception('Webob error seen')
                 raise  # Already converted to Webob exception, just reraise
+            # In case PolicyNotAuthorized, we do not want to expose payload by
+            # logging exception, so just LOG.error
+            except policy.PolicyNotAuthorized as pna:
+                status, message = api.generate_safe_exception_message(
+                    operation_name, pna)
+                LOG.error(message)
+                pecan.abort(status, message)
             except Exception as e:
                 # In case intervening modules have disabled logging.
                 LOG.logger.disabled = False
@@ -125,10 +133,9 @@ def _do_enforce_content_types(pecan_req, valid_content_types):
     """
     if pecan_req.content_type not in valid_content_types:
         m = u._(
-            "Unexpected content type: {type}. Expected content types "
+            "Unexpected content type. Expected content types "
             "are: {expected}"
         ).format(
-            type=pecan_req.content_type.decode('utf-8'),
             expected=valid_content_types
         )
         pecan.abort(415, m)
