@@ -10,6 +10,7 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
+from oslo_utils import timeutils
 import pecan
 from six.moves.urllib import parse
 
@@ -39,11 +40,25 @@ def _secret_not_found():
                          'another castle.'))
 
 
+def _invalid_secret_id():
+    """Throw exception indicating secret id is invalid."""
+    pecan.abort(404, u._('Not Found. Provided secret id is invalid.'))
+
+
+def _secret_payload_not_found():
+    """Throw exception indicating secret's payload is not found."""
+    pecan.abort(404, u._('Not Found. Sorry but your secret has no payload.'))
+
+
 def _secret_already_has_data():
     """Throw exception that the secret already has data."""
     pecan.abort(409, u._("Secret already has data, cannot modify it."))
 
 
+def _bad_query_string_parameters():
+    pecan.abort(400, u._("URI provided invalid query string parameters."))
+
+
 def _request_has_twsk_but_no_transport_key_id():
     """Throw exception for bad wrapping parameters.
 
@@ -103,12 +118,12 @@ class SecretController(controllers.ACLMixin):
         if controllers.is_json_request_accept(pecan.request):
             resp = self._on_get_secret_metadata(self.secret, **kwargs)
 
-            LOG.info(u._LI('Retrieved secret metadata for project: %s'),
+            LOG.info('Retrieved secret metadata for project: %s',
                      external_project_id)
             return resp
         else:
-            LOG.warning(u._LW('Decrypted secret %s requested using deprecated '
-                        'API call.'), self.secret.id)
+            LOG.warning('Decrypted secret %s requested using deprecated '
+                        'API call.', self.secret.id)
             return self._on_get_secret_payload(self.secret,
                                                external_project_id,
                                                **kwargs)
@@ -148,6 +163,10 @@ class SecretController(controllers.ACLMixin):
                                 'application/octet-stream')
         pecan.override_template('', accept_header)
 
+        # check if payload exists before proceeding
+        if not secret.encrypted_data and not secret.secret_store_metadata:
+            _secret_payload_not_found()
+
         twsk = kwargs.get('trans_wrapped_session_key', None)
         transport_key = None
 
@@ -178,13 +197,12 @@ class SecretController(controllers.ACLMixin):
     def payload(self, external_project_id, **kwargs):
         if pecan.request.method != 'GET':
             pecan.abort(405)
-        resp = self._on_get_secret_payload(
-            self.secret,
-            external_project_id,
-            **kwargs
-        )
 
-        LOG.info(u._LI('Retrieved secret payload for project: %s'),
+        resp = self._on_get_secret_payload(self.secret,
+                                           external_project_id,
+                                           **kwargs)
+
+        LOG.info('Retrieved secret payload for project: %s',
                  external_project_id)
         return resp
 
@@ -225,7 +243,7 @@ class SecretController(controllers.ACLMixin):
             secret_model=self.secret,
             project_model=project_model,
             transport_key_id=transport_key_id)
-        LOG.info(u._LI('Updated secret for project: %s'), external_project_id)
+        LOG.info('Updated secret for project: %s', external_project_id)
 
     @index.when(method='DELETE')
     @utils.allow_all_content_types
@@ -233,7 +251,7 @@ class SecretController(controllers.ACLMixin):
     @controllers.enforce_rbac('secret:delete')
     def on_delete(self, external_project_id, **kwargs):
         plugin.delete_secret(self.secret, external_project_id)
-        LOG.info(u._LI('Deleted secret for project: %s'), external_project_id)
+        LOG.info('Deleted secret for project: %s', external_project_id)
 
 
 class SecretsController(controllers.ACLMixin):
@@ -245,6 +263,60 @@ class SecretsController(controllers.ACLMixin):
         self.secret_repo = repo.get_secret_repository()
         self.quota_enforcer = quota.QuotaEnforcer('secrets', self.secret_repo)
 
+    def _is_valid_date_filter(self, date_filter):
+        filters = date_filter.split(',')
+        sorted_filters = dict()
+        try:
+            for filter in filters:
+                if filter.startswith('gt:'):
+                    if sorted_filters.get('gt') or sorted_filters.get('gte'):
+                        return False
+                    sorted_filters['gt'] = timeutils.parse_isotime(filter[3:])
+                elif filter.startswith('gte:'):
+                    if sorted_filters.get('gt') or sorted_filters.get(
+                            'gte') or sorted_filters.get('eq'):
+                        return False
+                    sorted_filters['gte'] = timeutils.parse_isotime(filter[4:])
+                elif filter.startswith('lt:'):
+                    if sorted_filters.get('lt') or sorted_filters.get('lte'):
+                        return False
+                    sorted_filters['lt'] = timeutils.parse_isotime(filter[3:])
+                elif filter.startswith('lte:'):
+                    if sorted_filters.get('lt') or sorted_filters.get(
+                            'lte') or sorted_filters.get('eq'):
+                        return False
+                    sorted_filters['lte'] = timeutils.parse_isotime(filter[4:])
+                elif sorted_filters.get('eq') or sorted_filters.get(
+                        'gte') or sorted_filters.get('lte'):
+                    return False
+                else:
+                    sorted_filters['eq'] = timeutils.parse_isotime(filter)
+        except ValueError:
+            return False
+        return True
+
+    def _is_valid_sorting(self, sorting):
+        allowed_keys = ['algorithm', 'bit_length', 'created',
+                        'expiration', 'mode', 'name', 'secret_type', 'status',
+                        'updated']
+        allowed_directions = ['asc', 'desc']
+        sorted_keys = dict()
+        for sort in sorting.split(','):
+            if ':' in sort:
+                try:
+                    key, direction = sort.split(':')
+                except ValueError:
+                    return False
+            else:
+                key, direction = sort, 'asc'
+            if key not in allowed_keys or direction not in allowed_directions:
+                return False
+            if sorted_keys.get(key):
+                return False
+            else:
+                sorted_keys[key] = direction
+        return True
+
     @pecan.expose()
     def _lookup(self, secret_id, *remainder):
         # NOTE(jaosorior): It's worth noting that even though this section
@@ -252,6 +324,8 @@ class SecretsController(controllers.ACLMixin):
         # check, the execution only gets here if authentication of the user was
         # previously successful.
 
+        if not utils.validate_id_is_uuid(secret_id):
+            _invalid_secret_id()()
         secret = self.secret_repo.get_secret_by_id(
             entity_id=secret_id, suppress_exception=True)
         if not secret:
@@ -285,22 +359,34 @@ class SecretsController(controllers.ACLMixin):
             # the default should be used.
             bits = 0
 
+        for date_filter in 'created', 'updated', 'expiration':
+            if kw.get(date_filter) and not self._is_valid_date_filter(
+                    kw.get(date_filter)):
+                _bad_query_string_parameters()
+        if kw.get('sort') and not self._is_valid_sorting(kw.get('sort')):
+            _bad_query_string_parameters()
+
         ctxt = controllers._get_barbican_context(pecan.request)
         user_id = None
         if ctxt:
             user_id = ctxt.user
 
-        result = self.secret_repo.get_by_create_date(
+        result = self.secret_repo.get_secret_list(
             external_project_id,
             offset_arg=kw.get('offset', 0),
-            limit_arg=kw.get('limit', None),
+            limit_arg=kw.get('limit'),
             name=name,
             alg=kw.get('alg'),
             mode=kw.get('mode'),
             bits=bits,
+            secret_type=kw.get('secret_type'),
             suppress_exception=True,
-            acl_only=kw.get('acl_only', None),
-            user_id=user_id
+            acl_only=kw.get('acl_only'),
+            user_id=user_id,
+            created=kw.get('created'),
+            updated=kw.get('updated'),
+            expiration=kw.get('expiration'),
+            sort=kw.get('sort')
         )
 
         secrets, offset, limit, total = result
@@ -319,7 +405,7 @@ class SecretsController(controllers.ACLMixin):
             )
             secrets_resp_overall.update({'total': total})
 
-        LOG.info(u._LI('Retrieved secret list for project: %s'),
+        LOG.info('Retrieved secret list for project: %s',
                  external_project_id)
         return secrets_resp_overall
 
@@ -328,7 +414,8 @@ class SecretsController(controllers.ACLMixin):
     @controllers.enforce_rbac('secrets:post')
     @controllers.enforce_content_types(['application/json'])
     def on_post(self, external_project_id, **kwargs):
-        LOG.debug('Start on_post for project-ID %s:...', external_project_id)
+        LOG.debug('Start on_post for project-ID %s:...',
+                  external_project_id)
 
         data = api.load_body(pecan.request, validator=self.validator)
         project = res.get_or_create_project(external_project_id)
@@ -359,7 +446,7 @@ class SecretsController(controllers.ACLMixin):
         pecan.response.status = 201
         pecan.response.headers['Location'] = url
 
-        LOG.info(u._LI('Created a secret for project: %s'),
+        LOG.info('Created a secret for project: %s',
                  external_project_id)
         if transport_key_model is not None:
             tkey_url = hrefs.convert_transport_key_to_href(
