@@ -257,8 +257,7 @@ class NewSecretValidator(ValidatorBase):
                     mime_types.is_supported(content_type),
                     schema_name,
                     u._("payload_content_type is not one of {supported}"
-                        ).format(supplied=content_type,
-                                 supported=mime_types.SUPPORTED),
+                        ).format(supported=mime_types.SUPPORTED),
                     "payload_content_type")
 
         return json_data
@@ -316,9 +315,8 @@ class NewSecretValidator(ValidatorBase):
         self._assert_validity(
             mime_types.is_supported(content_type),
             schema_name,
-            u._("payload_content_type {supplied} is not one of {supported}"
-                ).format(supplied=content_type,
-                         supported=mime_types.SUPPORTED),
+            u._("payload_content_type is not one of {supported}"
+                ).format(supported=mime_types.SUPPORTED),
             "payload_content_type")
 
         self._assert_validity(
@@ -364,7 +362,7 @@ class NewSecretMetadataValidator(ValidatorBase):
             "$schema": "http://json-schema.org/draft-03/schema",
             "properties": {
                 "metadata": {"type": "object", "required": True},
-                }
+            }
         }
 
     def validate(self, json_data, parent_schema=None):
@@ -762,8 +760,8 @@ class ContainerConsumerValidator(ValidatorBase):
         self.schema = {
             "type": "object",
             "properties": {
-                "URL": {"type": "string"},
-                "name": {"type": "string", "maxLength": 255}
+                "URL": {"type": "string", "minLength": 1},
+                "name": {"type": "string", "maxLength": 255, "minLength": 1}
             },
             "required": ["name", "URL"]
         }
@@ -775,6 +773,27 @@ class ContainerConsumerValidator(ValidatorBase):
         return json_data
 
 
+class ContainerSecretValidator(ValidatorBase):
+    """Validate a Container Secret."""
+
+    def __init__(self):
+        self.name = 'ContainerSecret'
+        self.schema = {
+            "type": "object",
+            "properties": {
+                "name": {"type": "string", "maxLength": 255},
+                "secret_ref": {"type": "string", "minLength": 1}
+            },
+            "required": ["secret_ref"]
+        }
+
+    def validate(self, json_data, parent_schema=None):
+        schema_name = self._full_name(parent_schema)
+
+        self._assert_schema_is_valid(json_data, schema_name)
+        return json_data
+
+
 class ContainerValidator(ValidatorBase):
     """Validator for all types of Container."""
 
@@ -840,9 +859,9 @@ class ContainerValidator(ValidatorBase):
 
         # Ensure that our secret refs are valid relative to our config, no
         # spoofing allowed!
-        configured_host_href = CONF.host_href
+        req_host_href = utils.get_base_url_from_request()
         for secret_ref in secret_refs:
-            if configured_host_href not in secret_ref.get('secret_ref'):
+            if not secret_ref.get('secret_ref').startswith(req_host_href):
                 raise exception.UnsupportedField(
                     field='secret_ref',
                     schema=schema_name,
@@ -860,8 +879,8 @@ class ContainerValidator(ValidatorBase):
         return json_data
 
     def _validate_rsa(self, secret_refs_names, schema_name):
-        required_names = set(['public_key', 'private_key'])
-        optional_names = set(['private_key_passphrase'])
+        required_names = {'public_key', 'private_key'}
+        optional_names = {'private_key_passphrase'}
         contains_unsupported_names = self._contains_unsupported_names(
             secret_refs_names, required_names | optional_names)
         self._assert_validity(
@@ -880,9 +899,9 @@ class ContainerValidator(ValidatorBase):
             "secret_refs")
 
     def _validate_certificate(self, secret_refs_names, schema_name):
-        required_names = set(['certificate'])
-        optional_names = set(['private_key', 'private_key_passphrase',
-                              'intermediates'])
+        required_names = {'certificate'}
+        optional_names = {'private_key', 'private_key_passphrase',
+                          'intermediates'}
         contains_unsupported_names = self._contains_unsupported_names(
             secret_refs_names, required_names.union(optional_names))
         self._assert_validity(
