@@ -1,3 +1,16 @@
+#
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
 """rename ACL creator_only to project_access
 
 Revision ID: 6a4457517a3
@@ -16,9 +29,6 @@ import sqlalchemy as sa
 
 def upgrade():
 
-    ctx = op.get_context()
-    con = op.get_bind()
-
     op.alter_column('secret_acls', 'creator_only', existing_type=sa.BOOLEAN(),
                     new_column_name='project_access')
 
