@@ -72,12 +72,19 @@ p11_crypto_plugin_opts = [
     cfg.StrOpt('plugin_name',
                help=u._('User friendly plugin name'),
                default='PKCS11 HSM'),
+    cfg.BoolOpt('generate_iv',
+                help=u._('Flag for plugin generated iv case'),
+                default=False),
 ]
 CONF.register_group(p11_crypto_plugin_group)
 CONF.register_opts(p11_crypto_plugin_opts, group=p11_crypto_plugin_group)
 config.parse_args(CONF)
 
 
+def list_opts():
+    yield p11_crypto_plugin_group, p11_crypto_plugin_opts
+
+
 def json_dumps_compact(data):
     return json.dumps(data, separators=(',', ':'))
 
@@ -145,7 +152,7 @@ class P11CryptoPlugin(plugin.CryptoPluginBase):
         try:
             return func(*args, **kwargs)
         except (exception.PKCS11Exception) as pe:
-            LOG.warning(u._LW("Reinitializing PKCS#11 library: %s"), pe)
+            LOG.warning("Reinitializing PKCS#11 library: %s", pe)
             self._reinitialize_pkcs11()
             return func(*args, **kwargs)
 
@@ -282,6 +289,7 @@ class P11CryptoPlugin(plugin.CryptoPluginBase):
             ffi=ffi,
             algorithm=plugin_conf.algorithm,
             seed_random_buffer=seed_random_buffer,
+            generate_iv=plugin_conf.generate_iv,
         )
 
     def _reinitialize_pkcs11(self):
