@@ -56,10 +56,10 @@ kmip_opts = [
                default='localhost',
                help=u._('Address of the KMIP server')
                ),
-    cfg.IntOpt('port',
-               default=5696,
-               help=u._('Port for the KMIP server'),
-               ),
+    cfg.PortOpt('port',
+                default=5696,
+                help=u._('Port for the KMIP server'),
+                ),
     cfg.StrOpt('ssl_version',
                default='PROTOCOL_TLSv1_2',
                help=u._('SSL version, maps to the module ssl\'s constants'),
