@@ -11,10 +11,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import base64
-
-from Crypto.PublicKey import RSA
+from cryptography.hazmat.backends import default_backend
+from cryptography.hazmat.primitives import serialization
 from OpenSSL import crypto
+from oslo_serialization import base64
+import six
 
 from barbican import i18n as u  # noqa
 from barbican.plugin.interface import secret_store as s
@@ -48,13 +49,16 @@ def normalize_before_encryption(unencrypted, content_type, content_encoding,
     # Process plain-text type.
     if normalized_media_type in mime_types.PLAIN_TEXT:
         # normalize text to binary and then base64 encode it
-        unencrypted_bytes = unencrypted.encode('utf-8')
-        b64payload = base64.b64encode(unencrypted_bytes)
+        if six.PY3:
+            b64payload = base64.encode_as_bytes(unencrypted)
+        else:
+            unencrypted_bytes = unencrypted.encode('utf-8')
+            b64payload = base64.encode_as_bytes(unencrypted_bytes)
 
     # Process binary type.
     else:
         if not content_encoding:
-            b64payload = base64.b64encode(unencrypted)
+            b64payload = base64.encode_as_bytes(unencrypted)
         elif content_encoding.lower() == 'base64':
             b64payload = unencrypted
         elif enforce_text_only:
@@ -96,14 +100,13 @@ def denormalize_after_decryption(unencrypted, content_type):
     if content_type in mime_types.PLAIN_TEXT:
         # normalize text to binary string
         try:
-            unencrypted = base64.b64decode(unencrypted)
-            unencrypted = unencrypted.decode('utf-8')
+            unencrypted = base64.decode_as_text(unencrypted)
         except UnicodeDecodeError:
             raise s.SecretAcceptNotSupportedException(content_type)
 
     # Process binary type.
     elif content_type in mime_types.BINARY:
-        unencrypted = base64.b64decode(unencrypted)
+        unencrypted = base64.decode_as_bytes(unencrypted)
     else:
         raise s.SecretContentTypeNotSupportedException(content_type)
 
@@ -135,26 +138,54 @@ def convert_der_to_pem(der, secret_type):
 
 
 def _convert_private_pem_to_der(pem):
-    private_key = RSA.importKey(pem)
-    der = private_key.exportKey('DER', pkcs=8)
+    private_key = serialization.load_pem_private_key(
+        pem,
+        password=None,
+        backend=default_backend()
+        )
+    der = private_key.private_bytes(
+        encoding=serialization.Encoding.DER,
+        format=serialization.PrivateFormat.PKCS8,
+        encryption_algorithm=serialization.NoEncryption()
+        )
     return der
 
 
 def _convert_private_der_to_pem(der):
-    private_key = RSA.importKey(der)
-    pem = private_key.exportKey('PEM', pkcs=8)
+    private_key = serialization.load_der_private_key(
+        der,
+        password=None,
+        backend=default_backend()
+        )
+    pem = private_key.private_bytes(
+        encoding=serialization.Encoding.PEM,
+        format=serialization.PrivateFormat.PKCS8,
+        encryption_algorithm=serialization.NoEncryption()
+        )
     return pem
 
 
 def _convert_public_pem_to_der(pem):
-    pubkey = RSA.importKey(pem)
-    der = pubkey.exportKey('DER')
+    public_key = serialization.load_pem_public_key(
+        pem,
+        backend=default_backend()
+        )
+    der = public_key.public_bytes(
+        encoding=serialization.Encoding.DER,
+        format=serialization.PublicFormat.SubjectPublicKeyInfo
+        )
     return der
 
 
 def _convert_public_der_to_pem(der):
-    pubkey = RSA.importKey(der)
-    pem = pubkey.exportKey('PEM')
+    public_key = serialization.load_der_public_key(
+        der,
+        backend=default_backend()
+        )
+    pem = public_key.public_bytes(
+        encoding=serialization.Encoding.PEM,
+        format=serialization.PublicFormat.SubjectPublicKeyInfo
+        )
     return pem
 
 
