@@ -14,6 +14,7 @@
 import mock
 import six
 
+from barbican.common import exception
 from barbican.plugin.crypto import pkcs11
 from barbican.tests import utils
 
@@ -28,6 +29,7 @@ class WhenTestingPKCS11(utils.BaseTestCase):
 
         self.lib = mock.Mock()
         self.lib.C_Initialize.return_value = pkcs11.CKR_OK
+        self.lib.C_Finalize.return_value = pkcs11.CKR_OK
         self.lib.C_OpenSession.side_effect = self._open_session
         self.lib.C_CloseSession.return_value = pkcs11.CKR_OK
         self.lib.C_GetSessionInfo.side_effect = self._get_session_user
@@ -37,6 +39,7 @@ class WhenTestingPKCS11(utils.BaseTestCase):
         self.lib.C_FindObjectsFinal.return_value = pkcs11.CKR_OK
         self.lib.C_GenerateKey.side_effect = self._generate_key
         self.lib.C_GenerateRandom.side_effect = self._generate_random
+        self.lib.C_SeedRandom.return_value = pkcs11.CKR_OK
         self.lib.C_EncryptInit.return_value = pkcs11.CKR_OK
         self.lib.C_Encrypt.side_effect = self._encrypt
         self.lib.C_DecryptInit.return_value = pkcs11.CKR_OK
@@ -105,7 +108,11 @@ class WhenTestingPKCS11(utils.BaseTestCase):
         return pkcs11.CKR_OK
 
     def _encrypt(self, session, pt, pt_len, ct, ct_len):
-        self.ffi.buffer(ct)[:] = pt[::-1] + b'0' * self.pkcs11.gcmtagsize
+        if self.pkcs11.generate_iv:
+            self.ffi.buffer(ct)[:] = pt[::-1] + b'0' * self.pkcs11.gcmtagsize
+        else:
+            self.ffi.buffer(ct)[:] = pt[::-1] + b'0' * (self.pkcs11.gcmtagsize
+                                                        * 2)
         return pkcs11.CKR_OK
 
     def _decrypt(self, session, ct, ct_len, pt, pt_len):
@@ -139,43 +146,50 @@ class WhenTestingPKCS11(utils.BaseTestCase):
         self.lib.C_GetSessionInfo.side_effect = self._get_session_public
         sess = self.pkcs11.get_session()
 
-        self.assertEqual(sess, 1)
+        self.assertEqual(1, sess)
 
-        self.assertEqual(self.lib.C_OpenSession.call_count, 2)
-        self.assertEqual(self.lib.C_GetSessionInfo.call_count, 2)
-        self.assertEqual(self.lib.C_Login.call_count, 1)
-        self.assertEqual(self.lib.C_CloseSession.call_count, 1)
+        self.assertEqual(2, self.lib.C_OpenSession.call_count)
+        self.assertEqual(2, self.lib.C_GetSessionInfo.call_count)
+        self.assertEqual(1, self.lib.C_Login.call_count)
+        self.assertEqual(1, self.lib.C_CloseSession.call_count)
 
     def test_user_get_session(self):
         self.pkcs11.get_session()
 
-        self.assertEqual(self.lib.C_OpenSession.call_count, 2)
-        self.assertEqual(self.lib.C_GetSessionInfo.call_count, 2)
-        self.assertEqual(self.lib.C_Login.call_count, 0)
+        self.assertEqual(2, self.lib.C_OpenSession.call_count)
+        self.assertEqual(2, self.lib.C_GetSessionInfo.call_count)
+        self.assertEqual(0, self.lib.C_Login.call_count)
+
+    def test_seed_random(self):
+        rd = "random-data"
+        session = 'session'
+        self.pkcs11._seed_random(session, rd)
+        self.lib.C_SeedRandom.assert_called_once_with(
+            session, mock.ANY, len(rd))
 
     def test_generate_random(self):
         r = self.pkcs11.generate_random(32, mock.MagicMock())
 
-        self.assertEqual(r, b'0' * 32)
+        self.assertEqual(b'0' * 32, r)
 
-        self.assertEqual(self.lib.C_GenerateRandom.call_count, 2)
+        self.assertEqual(2, self.lib.C_GenerateRandom.call_count)
 
     def test_rng_self_test_fail(self):
         def _bad_generate_random(session, buf, length):
             self.ffi.buffer(buf)[:] = b'\x00' * length
             return pkcs11.CKR_OK
         self.lib.C_GenerateRandom.side_effect = _bad_generate_random
-        self.assertRaises(pkcs11.P11CryptoPluginException,
+        self.assertRaises(exception.P11CryptoPluginException,
                           self.pkcs11._rng_self_test, mock.MagicMock())
 
     def test_get_key_handle_one_key(self):
         key = self.pkcs11.get_key_handle('foo', mock.MagicMock())
 
-        self.assertEqual(key, 2)
+        self.assertEqual(2, key)
 
-        self.assertEqual(self.lib.C_FindObjectsInit.call_count, 1)
-        self.assertEqual(self.lib.C_FindObjects.call_count, 1)
-        self.assertEqual(self.lib.C_FindObjectsFinal.call_count, 1)
+        self.assertEqual(1, self.lib.C_FindObjectsInit.call_count)
+        self.assertEqual(1, self.lib.C_FindObjects.call_count)
+        self.assertEqual(1, self.lib.C_FindObjectsFinal.call_count)
 
     def test_get_key_handle_no_keys(self):
         self.lib.C_FindObjects.side_effect = self._find_objects_zero
@@ -183,37 +197,37 @@ class WhenTestingPKCS11(utils.BaseTestCase):
 
         self.assertIsNone(key)
 
-        self.assertEqual(self.lib.C_FindObjectsInit.call_count, 1)
-        self.assertEqual(self.lib.C_FindObjects.call_count, 1)
-        self.assertEqual(self.lib.C_FindObjectsFinal.call_count, 1)
+        self.assertEqual(1, self.lib.C_FindObjectsInit.call_count)
+        self.assertEqual(1, self.lib.C_FindObjects.call_count)
+        self.assertEqual(1, self.lib.C_FindObjectsFinal.call_count)
 
     def test_get_key_handle_multiple_keys(self):
         self.lib.C_FindObjects.side_effect = self._find_objects_two
 
-        self.assertRaises(pkcs11.P11CryptoPluginKeyException,
+        self.assertRaises(exception.P11CryptoPluginKeyException,
                           self.pkcs11.get_key_handle, 'foo', mock.MagicMock())
 
-        self.assertEqual(self.lib.C_FindObjectsInit.call_count, 1)
-        self.assertEqual(self.lib.C_FindObjects.call_count, 1)
-        self.assertEqual(self.lib.C_FindObjectsFinal.call_count, 1)
+        self.assertEqual(1, self.lib.C_FindObjectsInit.call_count)
+        self.assertEqual(1, self.lib.C_FindObjects.call_count)
+        self.assertEqual(1, self.lib.C_FindObjectsFinal.call_count)
 
     def test_generate_session_key(self):
         key = self.pkcs11.generate_key(16, mock.MagicMock(), encrypt=True)
 
-        self.assertEqual(key, 3)
+        self.assertEqual(3, key)
 
-        self.assertEqual(self.lib.C_GenerateKey.call_count, 1)
+        self.assertEqual(1, self.lib.C_GenerateKey.call_count)
 
     def test_generate_master_key(self):
         key = self.pkcs11.generate_key(16, mock.MagicMock(), key_label='key',
                                        encrypt=True, master_key=True)
 
-        self.assertEqual(key, 3)
+        self.assertEqual(3, key)
 
-        self.assertEqual(self.lib.C_GenerateKey.call_count, 1)
+        self.assertEqual(1, self.lib.C_GenerateKey.call_count)
 
     def test_generate_key_no_flags(self):
-        self.assertRaises(pkcs11.P11CryptoPluginException,
+        self.assertRaises(exception.P11CryptoPluginException,
                           self.pkcs11.generate_key, mock.MagicMock(),
                           mock.MagicMock())
 
@@ -222,16 +236,29 @@ class WhenTestingPKCS11(utils.BaseTestCase):
                           mock.MagicMock(), mock.MagicMock(),
                           encrypt=True, master_key=True)
 
-    def test_encrypt(self):
+    def test_encrypt_with_no_iv_generation(self):
         pt = b'0123456789ABCDEF'
+        self.pkcs11.generate_iv = False
         ct = self.pkcs11.encrypt(mock.MagicMock(), pt, mock.MagicMock())
 
         self.assertEqual(ct['ct'][:len(pt)], pt[::-1])
         self.assertGreater(len(ct['iv']), 0)
 
-        self.assertEqual(self.lib.C_GenerateRandom.call_count, 2)
-        self.assertEqual(self.lib.C_EncryptInit.call_count, 1)
-        self.assertEqual(self.lib.C_Encrypt.call_count, 1)
+        self.assertEqual(1, self.lib.C_GenerateRandom.call_count)
+        self.assertEqual(1, self.lib.C_EncryptInit.call_count)
+        self.assertEqual(1, self.lib.C_Encrypt.call_count)
+
+    def test_encrypt_with_iv_generation(self):
+        pt = b'0123456789ABCDEF'
+        self.pkcs11.generate_iv = True
+        ct = self.pkcs11.encrypt(mock.MagicMock(), pt, mock.MagicMock())
+
+        self.assertEqual(ct['ct'][:len(pt)], pt[::-1])
+        self.assertGreater(len(ct['iv']), 0)
+
+        self.assertEqual(2, self.lib.C_GenerateRandom.call_count)
+        self.assertEqual(1, self.lib.C_EncryptInit.call_count)
+        self.assertEqual(1, self.lib.C_Encrypt.call_count)
 
     def test_decrypt(self):
         ct = b'FEDCBA9876543210' + b'0' * self.pkcs11.gcmtagsize
@@ -241,8 +268,8 @@ class WhenTestingPKCS11(utils.BaseTestCase):
         pt_len = len(ct) - self.pkcs11.gcmtagsize
         self.assertEqual(pt[:pt_len], ct[:-self.pkcs11.gcmtagsize][::-1])
 
-        self.assertEqual(self.lib.C_DecryptInit.call_count, 1)
-        self.assertEqual(self.lib.C_Decrypt.call_count, 1)
+        self.assertEqual(1, self.lib.C_DecryptInit.call_count)
+        self.assertEqual(1, self.lib.C_Decrypt.call_count)
 
     def test_decrypt_with_pad(self):
         ct = b'\x03\x03\x03CBA9876543210' + b'0' * self.pkcs11.gcmtagsize
@@ -252,8 +279,8 @@ class WhenTestingPKCS11(utils.BaseTestCase):
         pt_len = len(ct) - self.pkcs11.gcmtagsize - 3
         self.assertEqual(pt[:pt_len], ct[3:-self.pkcs11.gcmtagsize][::-1])
 
-        self.assertEqual(self.lib.C_DecryptInit.call_count, 1)
-        self.assertEqual(self.lib.C_Decrypt.call_count, 1)
+        self.assertEqual(1, self.lib.C_DecryptInit.call_count)
+        self.assertEqual(1, self.lib.C_Decrypt.call_count)
 
     def test_decrypt_with_pad_new_iv(self):
         ct = b'\x03\x03\x03CBA9876543210' + b'0' * self.pkcs11.gcmtagsize
@@ -263,8 +290,8 @@ class WhenTestingPKCS11(utils.BaseTestCase):
         pt_len = len(ct) - self.pkcs11.gcmtagsize
         self.assertEqual(pt[:pt_len], ct[:-self.pkcs11.gcmtagsize][::-1])
 
-        self.assertEqual(self.lib.C_DecryptInit.call_count, 1)
-        self.assertEqual(self.lib.C_Decrypt.call_count, 1)
+        self.assertEqual(1, self.lib.C_DecryptInit.call_count)
+        self.assertEqual(1, self.lib.C_Decrypt.call_count)
 
     def test_decrypt_with_pad_wrong_size(self):
         ct = b'\x03\x03\x03CBA987654321' + b'0' * self.pkcs11.gcmtagsize
@@ -274,8 +301,8 @@ class WhenTestingPKCS11(utils.BaseTestCase):
         pt_len = len(ct) - self.pkcs11.gcmtagsize
         self.assertEqual(pt[:pt_len], ct[:-self.pkcs11.gcmtagsize][::-1])
 
-        self.assertEqual(self.lib.C_DecryptInit.call_count, 1)
-        self.assertEqual(self.lib.C_Decrypt.call_count, 1)
+        self.assertEqual(1, self.lib.C_DecryptInit.call_count)
+        self.assertEqual(1, self.lib.C_Decrypt.call_count)
 
     def test_decrypt_with_pad_wrong_length(self):
         ct = b'\x03EDCBA9876543210' + b'0' * self.pkcs11.gcmtagsize
@@ -285,8 +312,8 @@ class WhenTestingPKCS11(utils.BaseTestCase):
         pt_len = len(ct) - self.pkcs11.gcmtagsize
         self.assertEqual(pt[:pt_len], ct[:-self.pkcs11.gcmtagsize][::-1])
 
-        self.assertEqual(self.lib.C_DecryptInit.call_count, 1)
-        self.assertEqual(self.lib.C_Decrypt.call_count, 1)
+        self.assertEqual(1, self.lib.C_DecryptInit.call_count)
+        self.assertEqual(1, self.lib.C_Decrypt.call_count)
 
     def test_decrypt_with_too_large_pad(self):
         ct = b'\x11EDCBA9876543210' + b'0' * self.pkcs11.gcmtagsize
@@ -296,44 +323,60 @@ class WhenTestingPKCS11(utils.BaseTestCase):
         pt_len = len(ct) - self.pkcs11.gcmtagsize
         self.assertEqual(pt[:pt_len], ct[:-self.pkcs11.gcmtagsize][::-1])
 
-        self.assertEqual(self.lib.C_DecryptInit.call_count, 1)
-        self.assertEqual(self.lib.C_Decrypt.call_count, 1)
+        self.assertEqual(1, self.lib.C_DecryptInit.call_count)
+        self.assertEqual(1, self.lib.C_Decrypt.call_count)
 
     def test_wrap_key(self):
         wkek = self.pkcs11.wrap_key(mock.Mock(), mock.Mock(), mock.Mock())
         self.assertGreater(len(wkek['iv']), 0)
-        self.assertEqual(wkek['wrapped_key'], b'0' * 16)
+        self.assertEqual(b'0' * 16, wkek['wrapped_key'])
 
-        self.assertEqual(self.lib.C_GenerateRandom.call_count, 2)
-        self.assertEqual(self.lib.C_WrapKey.call_count, 2)
+        self.assertEqual(2, self.lib.C_GenerateRandom.call_count)
+        self.assertEqual(2, self.lib.C_WrapKey.call_count)
 
     def test_unwrap_key(self):
         kek = self.pkcs11.unwrap_key(mock.Mock(), b'0' * 16,
                                      b'0' * 16, mock.Mock())
-        self.assertEqual(kek, 1)
+        self.assertEqual(1, kek)
 
         self.assertEqual(self.lib.C_UnwrapKey.call_count, 1)
 
     def test_compute_hmac(self):
         buf = self.pkcs11.compute_hmac(mock.MagicMock(), mock.MagicMock(),
                                        mock.MagicMock())
-        self.assertEqual(len(buf), 32)
+        self.assertEqual(32, len(buf))
 
-        self.assertEqual(self.lib.C_SignInit.call_count, 1)
-        self.assertEqual(self.lib.C_Sign.call_count, 1)
+        self.assertEqual(1, self.lib.C_SignInit.call_count)
+        self.assertEqual(1, self.lib.C_Sign.call_count)
 
     def test_verify_hmac(self):
         self.pkcs11.verify_hmac(mock.MagicMock(), mock.MagicMock(),
                                 mock.MagicMock(), mock.MagicMock())
 
-        self.assertEqual(self.lib.C_VerifyInit.call_count, 1)
-        self.assertEqual(self.lib.C_Verify.call_count, 1)
+        self.assertEqual(1, self.lib.C_VerifyInit.call_count)
+        self.assertEqual(1, self.lib.C_Verify.call_count)
 
     def test_destroy_object(self):
         self.pkcs11.destroy_object(mock.MagicMock(), mock.MagicMock())
 
-        self.assertEqual(self.lib.C_DestroyObject.call_count, 1)
+        self.assertEqual(1, self.lib.C_DestroyObject.call_count)
 
     def test_invalid_build_attributes(self):
         self.assertRaises(TypeError, self.pkcs11._build_attributes,
                           [pkcs11.Attribute(pkcs11.CKA_CLASS, {})])
+
+    def test_finalize(self):
+        self.pkcs11.finalize()
+
+        self.assertEqual(1, self.lib.C_Finalize.call_count)
+
+    def test_check_error(self):
+        self.assertIsNone(self.pkcs11._check_error(pkcs11.CKR_OK))
+
+    def test_check_error_with_without_specific_handling(self):
+        self.assertRaises(exception.P11CryptoPluginException,
+                          self.pkcs11._check_error, 5)
+
+    def test_check_error_with_token_error(self):
+        self.assertRaises(exception.P11CryptoTokenException,
+                          self.pkcs11._check_error, 0xe0)
