@@ -14,7 +14,8 @@
 # limitations under the License.
 import base64
 
-from Crypto.PublicKey import RSA
+from cryptography.hazmat.backends import default_backend
+from cryptography.hazmat.primitives import serialization
 from OpenSSL import crypto
 import testtools
 from testtools import testcase
@@ -142,9 +143,11 @@ class RSATestCase(base.TestCase):
         pem = keys.get_private_key_pem()
         crypto.load_privatekey(crypto.FILETYPE_PEM, pem)
 
-        # prove pyCrypto can parse the original public key
-        pem = keys.get_public_key_pem()
-        RSA.importKey(pem)
+        # prove cryptography can parse the original public key
+        serialization.load_pem_public_key(
+            keys.get_public_key_pem(),
+            backend=default_backend()
+        )
 
         # prove pyOpenSSL can parse the original encrypted private key
         pem = keys.get_encrypted_private_key_pem()
@@ -534,7 +537,7 @@ class RSATestCase(base.TestCase):
                              secret_dict['private_key_passphrase'])
             private_pem = keys.get_encrypted_private_key_pem()
         else:
-            self.assertFalse('private_key_passphrase' in secret_dict)
+            self.assertNotIn('private_key_passphrase', secret_dict)
             private_pem = keys.get_private_key_pem()
         self.assertEqual(private_pem, secret_dict['private_key'])
         public_pem = keys.get_public_key_pem()
@@ -550,11 +553,14 @@ class RSATestCase(base.TestCase):
                 secret_dict['private_key'],
                 secret_dict['private_key_passphrase'])
         else:
-            self.assertFalse('private_key_passphrase' in secret_dict)
+            self.assertNotIn('private_key_passphrase', secret_dict)
             crypto.load_privatekey(
                 crypto.FILETYPE_PEM,
                 secret_dict['private_key'])
-        RSA.importKey(secret_dict['public_key'])
+        serialization.load_pem_public_key(
+            secret_dict['public_key'],
+            backend=default_backend()
+        )
 
     def order_container(self, with_passphrase=False):
         if with_passphrase:
