@@ -82,7 +82,7 @@ class SecretMetadataTestCase(base.TestCase):
 
     @testcase.attr('negative')
     def test_secret_metadata_create_no_secret(self):
-        secret_ref = ('http://localhost:9311/secrets/%s' %
+        secret_ref = ('http://localhost/key-manager/secrets/%s' %
                       uuidutils.generate_uuid(dashed=False))
 
         meta_resp, metadata_ref = self.behaviors.create_or_update_metadata(
@@ -111,7 +111,7 @@ class SecretMetadataTestCase(base.TestCase):
 
     @testcase.attr('negative')
     def test_secret_metadata_get_no_secret(self):
-        secret_ref = ('http://localhost:9311/secrets/%s' %
+        secret_ref = ('http://localhost/key-manager/secrets/%s' %
                       uuidutils.generate_uuid(dashed=False))
 
         get_resp = self.behaviors.get_metadata(secret_ref)
