@@ -13,8 +13,8 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
-import json
 import logging
+from oslo_serialization import jsonutils
 
 LOG = logging.getLogger(__name__)
 
@@ -32,10 +32,9 @@ class BaseModel(object):
     def obj_to_json(self):
         """Convert this object to a JSON string.
 
-        :return A string of JSON containing the fields in this object
+        :return: A string of JSON containing the fields in this object
         """
-
-        return json.dumps(self.obj_to_dict())
+        return jsonutils.dump_as_bytes(self.obj_to_dict())
 
     def obj_to_dict(self):
         """Create a dict of the values for this model object.
@@ -43,7 +42,7 @@ class BaseModel(object):
         If there are  fields that are not set in this object then those
         will NOT have entries in the returned dict.
 
-        :return A dict representing this model
+        :return: A dict representing this model
         """
         the_dict = self.__dict__
         retval = self._remove_empty_fields_from_dict(the_dict)
@@ -72,10 +71,10 @@ class BaseModel(object):
         """Create a model from a JSON string.
 
         :param serialized_str: the JSON string
-        :return a secret object
+        :return: a secret object
         """
         try:
-            json_dict = json.loads(serialized_str)
+            json_dict = jsonutils.loads(serialized_str)
             return cls.dict_to_obj(json_dict)
         except TypeError as e:
             LOG.error('Couldn\'t deserialize input: %s\n Because: %s',
@@ -86,6 +85,6 @@ class BaseModel(object):
         """Create an object from a dict.
 
         :param input_dict: A dict of fields.
-        :return a model object build from the passed in dict.
+        :return: a model object build from the passed in dict.
         """
         return cls(**input_dict)
